@@ -28,7 +28,6 @@ pandas.options.mode.chained_assignment = None
 MENDELEEV_PROPERTY_LIST = [
     "abundance_crust",
     "abundance_sea",
-    "annotation",
     "atomic_number",
     "atomic_radius",
     "atomic_radius_rahm",
@@ -65,6 +64,7 @@ MENDELEEV_PROPERTY_LIST = [
     "electronegativity_gordy",
     "electronegativity_li_xue",
     "electronegativity_martynov_batsanov",
+    "electronegativity_mullay",
     "electronegativity_mulliken",
     "electronegativity_nagle",
     "electronegativity_pauling",
@@ -74,7 +74,11 @@ MENDELEEV_PROPERTY_LIST = [
     "electrophilicity",
     "en_allen",
     "en_ghosh",
+    "en_gunnarsson_lundqvist",
+    "en_miedema",
+    "en_mullay",
     "en_pauling",
+    "en_robles_bartolotti",
     "evaporation_heat",
     "fusion_heat",
     "gas_basicity",
@@ -91,6 +95,7 @@ MENDELEEV_PROPERTY_LIST = [
     "ionic_radii",
     "is_monoisotopic",
     "is_radioactive",
+    "isotope",
     "isotopes",
     "jmol_color",
     "lattice_constant",
@@ -103,6 +108,8 @@ MENDELEEV_PROPERTY_LIST = [
     "metadata",
     "metallic_radius",
     "metallic_radius_c12",
+    "miedema_electron_density",
+    "miedema_molar_volume",
     "molar_heat_capacity",
     "molcas_gv_color",
     "name",
@@ -116,9 +123,17 @@ MENDELEEV_PROPERTY_LIST = [
     "period",
     "pettifor_number",
     "phase_transitions",
+    "political_stability_of_top_producer",
+    "political_stability_of_top_reserve_holder",
+    "price_per_kg",
+    "production_concentration",
     "proton_affinity",
     "protons",
+    "recycling_rate",
     "registry",
+    "relative_supply_risk",
+    "reserve_distribution",
+    "scattering_factors",
     "sconst",
     "screening_constants",
     "series",
@@ -126,8 +141,11 @@ MENDELEEV_PROPERTY_LIST = [
     "sources",
     "specific_heat",
     "specific_heat_capacity",
+    "substitutability",
     "symbol",
     "thermal_conductivity",
+    "top_3_producers",
+    "top_3_reserve_holders",
     "uses",
     "vdw_radius",
     "vdw_radius_alvarez",
