@@ -3,9 +3,9 @@
 # Distributed under the terms of "New BSD License", see the LICENSE file.
 
 import numpy as np
+from pyiron_vasp.vasp.structure import write_poscar
 
 from pyiron_atomistics.atomistics.structure.atoms import Atoms
-from pyiron_atomistics.vasp.structure import write_poscar
 
 __author__ = "Sudarsan Surendralal, Su-Hyun Yoo"
 __copyright__ = (
