@@ -7,16 +7,16 @@ import pandas as pd
 import yaml
 from ase.io import read
 from pyiron_base import DataContainer, GenericJob
+from pyiron_lammps.structure import (
+    UnfoldingPrism,
+    structure_to_lammps,
+)
 from pyiron_snippets.import_alarm import ImportAlarm
 
 from pyiron_atomistics.atomistics.structure.atoms import Atoms, ase_to_pyiron
 from pyiron_atomistics.atomistics.structure.has_structure import HasStructure
 from pyiron_atomistics.lammps.potential import LammpsPotential, LammpsPotentialFile
-from pyiron_atomistics.lammps.structure import (
-    LammpsStructure,
-    UnfoldingPrism,
-    structure_to_lammps,
-)
+from pyiron_atomistics.lammps.structure import LammpsStructure
 
 calphy_version = "1.0.0"
 
@@ -27,7 +27,13 @@ with ImportAlarm(
     from calphy import Alchemy, Calculation, Liquid, Solid
     from calphy import __version__ as calphy_version
     from calphy.routines import routine_alchemy, routine_fe, routine_pscale, routine_ts
-    from pyscal.trajectory import Trajectory as PyscalTrajectory
+
+    # both trajectory classes behave the same, so we can use either depending
+    # on the env
+    try:
+        from pyscal.trajectory import Trajectory as PyscalTrajectory
+    except ImportError:
+        from pyscal3.trajectory import Trajectory as PyscalTrajectory
 
 __author__ = "Sarath Menon"
 __copyright__ = (
@@ -958,18 +964,29 @@ class Calphy(GenericJob, HasStructure):
             bp = []
             bc = []
 
+            def get_pos_cell(block):
+                di = block.to_dict()[0]
+                cc = di["box"]
+                if cc.shape[1] == 3:  # triclinic box, bail
+                    aseobj = block.to_ase(species=self._get_element_list())[0]
+                    return aseobj.positions, list(aseobj.cell)
+                pos = np.stack([di["atoms"]["x"], di["atoms"]["y"], di["atoms"]["z"]]).T
+                a, b, c = cc[:, 1] - cc[:, 0]
+                cell = list(np.diag([a, b, c]))
+                return pos, cell
+
             if os.path.exists(fwdfilename):
                 traj = PyscalTrajectory(fwdfilename)
-                for x in traj.nblocks:
-                    aseobj = traj[x].to_ase(species=self._get_element_list())
-                    fp.append(aseobj.positions)
-                    fc.append(list(aseobj.cell))
+                for x in range(traj.nblocks):
+                    pos, cell = get_pos_cell(traj[x])
+                    fp.append(pos)
+                    fc.append(cell)
             if os.path.exists(bkdfilename):
                 traj = PyscalTrajectory(bkdfilename)
-                for x in traj.nblocks:
-                    aseobj = traj[x].to_ase(species=self._get_element_list())
-                    bp.append(aseobj.positions)
-                    bc.append(list(aseobj.cell))
+                for x in range(traj.nblocks):
+                    pos, cell = get_pos_cell(traj[x])
+                    bp.append(pos)
+                    bc.append(cell)
 
             fwd_positions.append(fp)
             bkd_positions.append(bp)
