@@ -12,14 +12,15 @@ from typing import Optional
 import numpy as np
 import pandas
 from pyiron_base import state
+from pyiron_lammps.output import parse_lammps_output
+from pyiron_lammps.structure import UnfoldingPrism, structure_to_lammps
+from pyiron_lammps.units import LAMMPS_UNIT_CONVERSIONS
 from pyiron_snippets.deprecate import deprecate
+from pyiron_snippets.logger import logger
 
 from pyiron_atomistics.atomistics.job.atomistic import AtomisticGenericJob
 from pyiron_atomistics.lammps.control import LammpsControl
-from pyiron_atomistics.lammps.output import (
-    parse_lammps_output,
-    remap_indices,
-)
+from pyiron_atomistics.lammps.output import remap_indices
 from pyiron_atomistics.lammps.potential import (
     LammpsPotential,
     LammpsPotentialFile,
@@ -27,12 +28,7 @@ from pyiron_atomistics.lammps.potential import (
     list_potentials,
     view_potentials,
 )
-from pyiron_atomistics.lammps.structure import (
-    LammpsStructure,
-    UnfoldingPrism,
-    structure_to_lammps,
-)
-from pyiron_atomistics.lammps.units import LAMMPS_UNIT_CONVERSIONS
+from pyiron_atomistics.lammps.structure import LammpsStructure
 
 __author__ = "Joerg Neugebauer, Sudarsan Surendralal, Jan Janssen"
 __copyright__ = (
@@ -108,7 +104,7 @@ class LammpsBase(AtomisticGenericJob):
     @property
     def potential(self):
         """
-        Execute view_potential() or list_potential() in order to see the pre-defined potential files
+        Execute view_potentials() or list_potentials() in order to see the pre-defined potential files
 
         Returns:
 
@@ -118,7 +114,7 @@ class LammpsBase(AtomisticGenericJob):
     @potential.setter
     def potential(self, potential_filename):
         """
-        Execute view_potential() or list_potential() in order to see the pre-defined potential files
+        Execute view_potentials() or list_potentials() in order to see the pre-defined potential files
 
         Args:
             potential_filename:
@@ -416,6 +412,7 @@ class LammpsBase(AtomisticGenericJob):
             "dump_h5_file_name": "dump.h5",
             "dump_out_file_name": "dump.out",
             "log_lammps_file_name": "log.lammps",
+            "remap_indices_funct": remap_indices,
         }
 
     def save_output(
@@ -427,17 +424,22 @@ class LammpsBase(AtomisticGenericJob):
             data_dict=output_dict,
             group_name="output",
         )
-        final_structure = self.structure.copy()
-        final_structure.indices = hdf_dict["output/generic/indices"][-1]
-        final_structure.positions = hdf_dict["output/generic/positions"][-1]
-        final_structure.cell = hdf_dict["output/generic/cells"][-1]
-        if final_structure is not None:
+        if len(self.structure) == len(hdf_dict["output/generic/indices"][-1]):
+            final_structure = self.structure.copy()
+            final_structure.indices = hdf_dict["output/generic/indices"][-1]
+            final_structure.positions = hdf_dict["output/generic/positions"][-1]
+            final_structure.cell = hdf_dict["output/generic/cells"][-1]
             hdf_dict.update(
                 {
                     "output/structure/" + k: v
                     for k, v in final_structure.to_dict().items()
                 }
             )
+        else:
+            logger.warning(
+                "The number of atoms changed during the simulation. This can be a sign of massive issues in your simulation.\n"
+                "Not storing 'output/structure' to HDF"
+            )
         self.project_hdf5.write_dict_to_hdf(data_dict=hdf_dict)
 
     def convergence_check(self):
@@ -968,7 +970,10 @@ class LammpsBase(AtomisticGenericJob):
                         )
 
     def _get_lammps_structure(self, structure=None, cutoff_radius=None):
-        lmp_structure = LammpsStructure(bond_dict=self.input.bond_dict, job=self)
+        lmp_structure = LammpsStructure(
+            bond_dict=self.input.bond_dict,
+            job=self,
+        )
         lmp_structure._force_skewed = self.input.control._force_skewed
         lmp_structure.potential = self.input.potential
         lmp_structure.atom_type = self.input.control["atom_style"]
