@@ -19,24 +19,27 @@ import scipy.constants
 import spglib
 from pyiron_base import DataContainer, job_status_successful_lst, state
 from pyiron_snippets.deprecate import deprecate
+from sphinx_parser.output import (
+    SphinxLogParser,
+    collect_energy_dat,
+    collect_energy_struct,
+    collect_eps_dat,
+    collect_eval_forces,
+    collect_residue_dat,
+    collect_spins_dat,
+)
 
 from pyiron_atomistics.dft.job.generic import GenericDFTJob
-from pyiron_atomistics.dft.waves.electronic import ElectronicStructure
+from pyiron_atomistics.dft.waves.electronic import (
+    ElectronicStructure,
+    electronic_structure_dict_to_hdf,
+)
 from pyiron_atomistics.sphinx.input_writer import (
     Group,
     copy_potentials,
     get_structure_group,
     write_spin_constraints,
 )
-from pyiron_atomistics.sphinx.output_parser import (
-    SphinxLogParser,
-    collect_energy_dat,
-    collect_energy_struct,
-    collect_eps_dat,
-    collect_relaxed_hist,
-    collect_residue_dat,
-    collect_spins_dat,
-)
 from pyiron_atomistics.sphinx.potential import SphinxJTHPotentialFile
 from pyiron_atomistics.sphinx.structure import read_atoms
 from pyiron_atomistics.sphinx.util import sxversions
@@ -1032,15 +1035,12 @@ class SphinxBase(GenericDFTJob):
             ionic_force_tolerance = ionic_forces
         if ionic_energy is not None:
             ionic_energy_tolerance = ionic_energy
-        assert (
-            ionic_energy_tolerance is None or ionic_energy_tolerance > 0
-        ), "ionic_energy_tolerance must be a positive float"
-        assert (
-            ionic_force_tolerance is None or ionic_force_tolerance > 0
-        ), "ionic_force_tolerance must be a positive float"
-        assert (
-            electronic_energy is None or electronic_energy > 0
-        ), "electronic_energy must be a positive float"
+        cond = ionic_energy_tolerance is None or ionic_energy_tolerance > 0
+        assert cond, "ionic_energy_tolerance must be a positive float"
+        cond = ionic_force_tolerance is None or ionic_force_tolerance > 0
+        assert cond, "ionic_force_tolerance must be a positive float"
+        cond = electronic_energy is None or electronic_energy > 0
+        assert cond, "electronic_energy must be a positive float"
         if ionic_energy_tolerance is not None or ionic_force_tolerance is not None:
             # self.input["dE"] = ionic_energy_tolerance
             # self.input["dF"] = ionic_force_tolerance
@@ -1312,9 +1312,8 @@ class SphinxBase(GenericDFTJob):
                 potential_path = potentials.find_potential_file(
                     path=potentials.find_default(new_element)["Filename"].values[0][0]
                 )
-                assert os.path.isfile(
-                    potential_path
-                ), "such a file does not exist in the pp directory"
+                cond = os.path.isfile(potential_path)
+                assert cond, "such a file does not exist in the pp directory"
             elif elem in modified_elements.keys():
                 new_element = modified_elements[elem]
                 if os.path.isabs(new_element):
@@ -1911,7 +1910,8 @@ class Output:
         """
         try:
             results = collect_spins_dat(
-                file_name=file_name, cwd=cwd, index_permutation=self._job.id_spx_to_pyi
+                file_name=os.path.join(cwd, file_name),
+                index_permutation=self._job.id_spx_to_pyi,
             )
         except FileNotFoundError:
             return
@@ -1929,11 +1929,16 @@ class Output:
 
         """
         try:
-            results = collect_energy_dat(file_name=file_name, cwd=cwd)
+            results = collect_energy_dat(file_name=os.path.join(cwd, file_name))
         except FileNotFoundError:
             return
         for k, v in results.items():
-            self.generic.dft[k] = v
+            if k != "scf_computation_time":
+                self.generic.dft[k] = [
+                    (np.array(el) * HARTREE_TO_EV).tolist() for el in v
+                ]
+            else:
+                self.generic.dft[k] = v
 
     def collect_residue_dat(self, file_name="residue.dat", cwd=None):
         """
@@ -1946,7 +1951,7 @@ class Output:
 
         """
         try:
-            results = collect_residue_dat(file_name=file_name, cwd=cwd)
+            results = collect_residue_dat(file_name=os.path.join(cwd, file_name))
         except FileNotFoundError:
             return
         for k, v in results.items():
@@ -1964,7 +1969,8 @@ class Output:
         """
         try:
             results = collect_eps_dat(
-                file_name=file_name, cwd=cwd, spins=self._job._spin_enabled
+                cwd=cwd,
+                spins=self._job._spin_enabled,
             )
             for k, v in results.items():
                 if k not in self.generic.dft:
@@ -1983,11 +1989,11 @@ class Output:
 
         """
         try:
-            results = collect_energy_struct(file_name=file_name, cwd=cwd)
+            results = collect_energy_struct(file_name=os.path.join(cwd, file_name))
         except FileNotFoundError:
             return
         for k, v in results.items():
-            self.generic.dft[k] = v
+            self.generic.dft[k] = v * HARTREE_TO_EV
 
     def collect_sphinx_log(self, file_name="sphinx.log", cwd=None):
         """
@@ -1999,11 +2005,14 @@ class Output:
         Returns:
 
         """
+        if cwd is not None:
+            file_name = os.path.join(cwd, file_name)
 
         try:
-            results = SphinxLogParser(
-                file_name=file_name, cwd=cwd, index_permutation=self._job.id_spx_to_pyi
-            ).results
+            with open(file_name, "r") as f:
+                results = SphinxLogParser(
+                    file_content=f.read(), index_permutation=self._job.id_spx_to_pyi
+                ).results
         except FileNotFoundError:
             return None
         if len(results) == 0:
@@ -2012,11 +2021,23 @@ class Output:
         if not results["generic"].pop("job_finished"):
             self._job.status.aborted = True
         for key, value in results["generic"].items():
-            if key not in self.generic:
+            if key not in self.generic and key == "forces":
+                self.generic[key] = value * HARTREE_OVER_BOHR_TO_EV_OVER_ANGSTROM
+            elif key not in self.generic and key == "volume":
+                self.generic[key] = value * BOHR_TO_ANGSTROM**3
+            elif key not in self.generic:
                 self.generic[key] = value
         for key, value in results["dft"].items():
-            if key not in self.generic.dft:
+            if key not in self.generic.dft and key not in [
+                "scf_energy_int",
+                "scf_energy_free",
+                "scf_magnetic_forces",
+            ]:
                 self.generic.dft[key] = value
+            elif key not in self.generic.dft:
+                self.generic.dft[key] = [
+                    (np.array(el) * HARTREE_TO_EV).tolist() for el in value
+                ]
 
     def collect_relaxed_hist(self, file_name="relaxHist.sx", cwd=None):
         """
@@ -2029,13 +2050,19 @@ class Output:
 
         """
         try:
-            results = collect_relaxed_hist(
-                file_name=file_name, cwd=cwd, index_permutation=self._job.id_spx_to_pyi
+            results = collect_eval_forces(
+                file_name=os.path.join(cwd, file_name),
+                index_permutation=self._job.id_spx_to_pyi,
             )
         except FileNotFoundError:
             return
         for k, v in results.items():
-            self.generic[k] = v
+            if k == "forces":
+                self.generic[k] = v * HARTREE_OVER_BOHR_TO_EV_OVER_ANGSTROM
+            elif k in ["positions", "cell"]:
+                self.generic[k] = v * BOHR_TO_ANGSTROM
+            else:
+                self.generic[k] = v
 
     def collect_charge_density(self, file_name, cwd):
         if (
@@ -2132,7 +2159,11 @@ class Output:
                 try:
                     es = self._get_electronic_structure_object()
                     if len(es.kpoint_list) > 0:
-                        es.to_hdf(hdf5_output)
+                        electronic_structure_dict_to_hdf(
+                            data_dict=es.to_dict(),
+                            hdf=hdf5_output,
+                            group_name="electronic_structure",
+                        )
                 except IndexError:
                     warnings.warn("Electronic structure parsing failed")
             with hdf5_output.open("electronic_structure") as hdf5_es:
